from .flux import FluxClient, FluxEvent
from .config import Config
from .errors import *

__package__ = "aurflux"
__all__ = ["FluxClient", "FluxEvent"]
